@@ -1,18 +1,20 @@
 """Testing file path evaluation when using import_tasks / include_tasks."""
+from __future__ import annotations
+
 import textwrap
 from pathlib import Path
-from typing import Dict
 
 import pytest
 
 from ansiblelint.rules import RulesCollection
 from ansiblelint.runner import Runner
 
-LAYOUT_IMPORTS: Dict[str, str] = {
+LAYOUT_IMPORTS: dict[str, str] = {
     "main.yml": textwrap.dedent(
         """\
         ---
-        - hosts: target
+        - name: Fixture
+          hosts: target
           gather_facts: false
           tasks:
             - name: From main import task 1
@@ -37,57 +39,58 @@ LAYOUT_IMPORTS: Dict[str, str] = {
         """\
         ---
         - name: From subtask 1 import subtask 2
-          import_tasks: tasks/subtasks/subtask_2.yml
+          ansible.builtin.import_tasks: tasks/subtasks/subtask_2.yml
         """
     ),
     "tasks/subtasks/subtask_2.yml": textwrap.dedent(
         """\
         ---
         - name: From subtask 2 do something
-          debug:  # <-- expected to raise fqcn-builtins
+          debug:  # <-- expected to raise fqcn[action-core]
             msg: |
               Something...
         """
     ),
 }
 
-LAYOUT_INCLUDES: Dict[str, str] = {
+LAYOUT_INCLUDES: dict[str, str] = {
     "main.yml": textwrap.dedent(
         """\
         ---
-        - hosts: target
+        - name: Fixture
+          hosts: target
           gather_facts: false
           tasks:
             - name: From main import task 1
-              include_tasks: tasks/task_1.yml
+              ansible.builtin.include_tasks: tasks/task_1.yml
         """
     ),
     "tasks/task_1.yml": textwrap.dedent(
         """\
         ---
         - name: From task 1 import task 2
-          include_tasks: tasks/task_2.yml
+          ansible.builtin.include_tasks: tasks/task_2.yml
         """
     ),
     "tasks/task_2.yml": textwrap.dedent(
         """\
         ---
         - name: From task 2 import subtask 1
-          include_tasks: tasks/subtasks/subtask_1.yml
+          ansible.builtin.include_tasks: tasks/subtasks/subtask_1.yml
         """
     ),
     "tasks/subtasks/subtask_1.yml": textwrap.dedent(
         """\
         ---
         - name: From subtask 1 import subtask 2
-          include_tasks: tasks/subtasks/subtask_2.yml
+          ansible.builtin.include_tasks: tasks/subtasks/subtask_2.yml
         """
     ),
     "tasks/subtasks/subtask_2.yml": textwrap.dedent(
         """\
         ---
         - name: From subtask 2 do something
-          debug:  # <-- expected to raise fqcn-builtins
+          debug:  # <-- expected to raise fqcn[action-core]
             msg: |
               Something...
         """
@@ -105,7 +108,7 @@ LAYOUT_INCLUDES: Dict[str, str] = {
 def test_file_path_evaluation(
     tmp_path: Path,
     default_rules_collection: RulesCollection,
-    ansible_project_layout: Dict[str, str],
+    ansible_project_layout: dict[str, str],
 ) -> None:
     """Test file path evaluation when using import_tasks / include_tasks in the project.
 
@@ -120,4 +123,4 @@ def test_file_path_evaluation(
     result = Runner(str(tmp_path), rules=default_rules_collection).run()
 
     assert len(result) == 1
-    assert result[0].rule.id == "fqcn-builtins"
+    assert result[0].rule.id == "fqcn"
